﻿using System;

namespace DBExistsTest
{
    class Program
    {
        public enum SqlType {
            MySQL,
            SQLExpress
        };

        static void Main(string[] args)
        {
            Test("DBExistsTest", "test", "test", SqlType.MySQL);
        }

        static void Test(string dbName, string dbUser, string dbPassword, SqlType sqlType)
        {
            string connectStr = ConnectionString(dbName, dbUser, dbPassword, sqlType);
            var context = new dbexiststestEntities(connectStr);

            // Shows the creation script:
            Console.WriteLine("context.CreateDatabaseScript() output:\n{0}", context.CreateDatabaseScript());

            try
            {
                // Tests if the database exists:
                Console.WriteLine("{0}: DatabaseExists({1}) = {2}", sqlType, dbName, context.DatabaseExists());
            }
            catch (Exception e)
            {
                Console.WriteLine("DatabaseExists() triggered an exception:\n{0}\n", e.ToString());
            }

            try
            {
                context.CreateDatabase();
            }
            catch (Exception e) {
                Console.WriteLine("CreateDatabase() triggered an exception:\n{0}\n", e.ToString());
            }
            
            // Tries to read from the database:
            try
            {
                foreach (user u in context.users)
                    Console.WriteLine("User #{0}: {1}", u.id, u.name);
            }
            catch (Exception e)
            {
                Console.WriteLine("Could not read from database:\n{0}\n");
            }
        }

        static string ConnectionString(string dbName, string dbUser, string dbPassword, SqlType sqlType)
        {
            string cstring = null;
            switch (sqlType) {
                case SqlType.MySQL:
                    cstring = "metadata=res://*/EFUsers.csdl|res://*/EFUsers.ssdl|res://*/EFUsers.msl;provider=MySql.Data.MySqlClient;provider connection string=\"server=localhost;User Id={0};password={1};Persist Security Info=True;database={2}\"";
                    break;
                case SqlType.SQLExpress:
                    cstring = @"metadata=res://*/EFUsers.csdl|res://*/EFUsers.ssdl|res://*/EFUsers.msl;provider=System.Data.SqlClient;provider connection string=""Data Source=ODIN\SQLEXPRESS;Initial Catalog={2};Integrated Security=True""";
                    break;
            }
            return string.Format(cstring, dbUser, dbPassword, dbName);
        }

    }
}
